@@ -20,15 +20,15 @@ pub use bytes::Bytes;
 ///
 /// This is used in axum as the response body type for applications. Its
 /// necessary to unify multiple response bodies types into one.
-pub type BoxBody = http_body::combinators::BoxBody<Bytes, Error>;
+pub type BoxBody = http_body::combinators::UnsyncBoxBody<Bytes, Error>;
 
 /// Convert a [`http_body::Body`] into a [`BoxBody`].
 pub fn box_body<B>(body: B) -> BoxBody
 where
-    B: http_body::Body<Data = Bytes> + Send + Sync + 'static,
+    B: http_body::Body<Data = Bytes> + Send + 'static,
     B::Error: Into<BoxError>,
 {
-    body.map_err(Error::new).boxed()
+    body.map_err(Error::new).boxed_unsync()
 }
 
 pub(crate) fn empty() -> BoxBody {
