@@ -5,6 +5,7 @@
 //! [`Router::into_make_service_with_connect_info`]: crate::routing::Router::into_make_service_with_connect_info
 
 use super::{Extension, FromRequest, RequestParts};
+use crate::{AddExtension, AddExtensionLayer};
 use async_trait::async_trait;
 use hyper::server::conn::AddrStream;
 use std::future::ready;
@@ -15,7 +16,7 @@ use std::{
     net::SocketAddr,
     task::{Context, Poll},
 };
-use tower_http::add_extension::AddExtension;
+use tower_layer::Layer;
 use tower_service::Service;
 
 /// A [`MakeService`] created from a router.
@@ -33,7 +34,6 @@ pub struct IntoMakeServiceWithConnectInfo<S, C> {
 fn traits() {
     use crate::tests::*;
     assert_send::<IntoMakeServiceWithConnectInfo<(), NotSendSync>>();
-    assert_sync::<IntoMakeServiceWithConnectInfo<(), NotSendSync>>();
 }
 
 impl<S, C> IntoMakeServiceWithConnectInfo<S, C> {
@@ -65,18 +65,13 @@ where
 /// See [`Router::into_make_service_with_connect_info`] for more details.
 ///
 /// [`Router::into_make_service_with_connect_info`]: crate::routing::Router::into_make_service_with_connect_info
-pub trait Connected<T> {
-    /// The connection information type the IO resources generates.
-    type ConnectInfo: Clone + Send + Sync + 'static;
-
+pub trait Connected<T>: Clone + Send + Sync + 'static {
     /// Create type holding information about the connection.
-    fn connect_info(target: T) -> Self::ConnectInfo;
+    fn connect_info(target: T) -> Self;
 }
 
 impl Connected<&AddrStream> for SocketAddr {
-    type ConnectInfo = SocketAddr;
-
-    fn connect_info(target: &AddrStream) -> Self::ConnectInfo {
+    fn connect_info(target: &AddrStream) -> Self {
         target.remote_addr()
     }
 }
@@ -86,27 +81,26 @@ where
     S: Clone,
     C: Connected<T>,
 {
-    type Response = AddExtension<S, ConnectInfo<C::ConnectInfo>>;
+    type Response = AddExtension<S, ConnectInfo<C>>;
     type Error = Infallible;
-    type Future = ResponseFuture<Self::Response>;
+    type Future = ResponseFuture<S, C>;
 
+    #[inline]
     fn poll_ready(&mut self, _cx: &mut Context<'_>) -> Poll<Result<(), Self::Error>> {
         Poll::Ready(Ok(()))
     }
 
     fn call(&mut self, target: T) -> Self::Future {
         let connect_info = ConnectInfo(C::connect_info(target));
-        let svc = AddExtension::new(self.svc.clone(), connect_info);
-        ResponseFuture {
-            future: ready(Ok(svc)),
-        }
+        let svc = AddExtensionLayer::new(connect_info).layer(self.svc.clone());
+        ResponseFuture::new(ready(Ok(svc)))
     }
 }
 
 opaque_future! {
     /// Response future for [`IntoMakeServiceWithConnectInfo`].
-    pub type ResponseFuture<T> =
-        std::future::Ready<Result<T, Infallible>>;
+    pub type ResponseFuture<S, C> =
+        std::future::Ready<Result<AddExtension<S, ConnectInfo<C>>, Infallible>>;
 }
 
 /// Extractor for getting connection information produced by a [`Connected`].
@@ -139,7 +133,7 @@ where
 mod tests {
     use super::*;
     use crate::Server;
-    use crate::{handler::get, Router};
+    use crate::{routing::get, Router};
     use std::net::{SocketAddr, TcpListener};
 
     #[tokio::test]
@@ -177,9 +171,7 @@ mod tests {
         }
 
         impl Connected<&AddrStream> for MyConnectInfo {
-            type ConnectInfo = Self;
-
-            fn connect_info(_target: &AddrStream) -> Self::ConnectInfo {
+            fn connect_info(_target: &AddrStream) -> Self {
                 Self {
                     value: "it worked!",
                 }
