@@ -22,7 +22,7 @@ use std::{
 /// ```rust,no_run
 /// use axum::{
 ///     extract::Multipart,
-///     handler::post,
+///     routing::post,
 ///     Router,
 /// };
 /// use futures::stream::StreamExt;
@@ -53,7 +53,7 @@ pub struct Multipart {
 impl<B> FromRequest<B> for Multipart
 where
     B: http_body::Body<Data = Bytes> + Default + Unpin + Send + 'static,
-    B::Error: Into<BoxError> + 'static,
+    B::Error: Into<BoxError>,
 {
     type Rejection = MultipartRejection;
 
