@@ -25,9 +25,11 @@ define_rejection! {
     pub struct HeadersAlreadyExtracted;
 }
 
+#[cfg(feature = "json")]
 define_rejection! {
     #[status = BAD_REQUEST]
     #[body = "Failed to parse the request body as JSON"]
+    #[cfg_attr(docsrs, doc(cfg(feature = "json")))]
     /// Rejection type for [`Json`](super::Json).
     pub struct InvalidJsonBody(Error);
 }
@@ -105,7 +107,7 @@ define_rejection! {
 /// Rejection type for [`Path`](super::Path) if the capture route
 /// param didn't have the expected type.
 #[derive(Debug)]
-pub struct InvalidPathParam(String);
+pub struct InvalidPathParam(pub(crate) String);
 
 impl InvalidPathParam {
     pub(super) fn new(err: impl Into<String>) -> Self {
@@ -199,11 +201,13 @@ composite_rejection! {
     }
 }
 
+#[cfg(feature = "json")]
 composite_rejection! {
     /// Rejection used for [`Json`](super::Json).
     ///
     /// Contains one variant for each way the [`Json`](super::Json) extractor
     /// can fail.
+    #[cfg_attr(docsrs, doc(cfg(feature = "json")))]
     pub enum JsonRejection {
         InvalidJsonBody,
         MissingJsonContentType,
@@ -269,6 +273,23 @@ composite_rejection! {
     }
 }
 
+define_rejection! {
+    #[status = INTERNAL_SERVER_ERROR]
+    #[body = "No matched path found"]
+    /// Rejection if no matched path could be found.
+    ///
+    /// See [`MatchedPath`](super::MatchedPath) for more details.
+    pub struct MatchedPathMissing;
+}
+
+composite_rejection! {
+    /// Rejection used for [`MatchedPath`](super::MatchedPath).
+    pub enum MatchedPathRejection {
+        ExtensionsAlreadyExtracted,
+        MatchedPathMissing,
+    }
+}
+
 /// Rejection used for [`ContentLengthLimit`](super::ContentLengthLimit).
 ///
 /// Contains one variant for each way the
