@@ -5,7 +5,7 @@
 //! ```
 //! use axum::{
 //!     extract::ws::{WebSocketUpgrade, WebSocket},
-//!     handler::get,
+//!     routing::get,
 //!     response::IntoResponse,
 //!     Router,
 //! };
@@ -87,7 +87,7 @@ use std::{
 };
 use tokio_tungstenite::{
     tungstenite::{
-        self,
+        self as ts,
         protocol::{self, WebSocketConfig},
     },
     WebSocketStream,
@@ -96,7 +96,7 @@ use tokio_tungstenite::{
 /// Extractor for establishing WebSocket connections.
 ///
 /// Note: This extractor requires the request method to be `GET` so it should
-/// always be used with [`get`](crate::handler::get). Requests with other methods will be
+/// always be used with [`get`](crate::routing::get). Requests with other methods will be
 /// rejected.
 ///
 /// See the [module docs](self) for an example.
@@ -138,7 +138,7 @@ impl WebSocketUpgrade {
     /// ```
     /// use axum::{
     ///     extract::ws::{WebSocketUpgrade, WebSocket},
-    ///     handler::get,
+    ///     routing::get,
     ///     response::IntoResponse,
     ///     Router,
     /// };
@@ -209,7 +209,7 @@ where
         }
 
         if !header_eq(req, header::SEC_WEBSOCKET_VERSION, "13")? {
-            return Err(InvalidWebsocketVersionHeader.into());
+            return Err(InvalidWebSocketVersionHeader.into());
         }
 
         let sec_websocket_key = if let Some(key) = req
@@ -219,7 +219,7 @@ where
         {
             key
         } else {
-            return Err(WebsocketKeyHeaderMissing.into());
+            return Err(WebSocketKeyHeaderMissing.into());
         };
 
         let on_upgrade = req
@@ -309,7 +309,7 @@ where
                 } else {
                     return (
                         StatusCode::BAD_REQUEST,
-                        "`Sec-Websocket-Protocol` header is invalid",
+                        "`Sec-WebSocket-Protocol` header is invalid",
                     )
                         .into_response();
                 }
@@ -468,35 +468,31 @@ pub enum Message {
 }
 
 impl Message {
-    fn into_tungstenite(self) -> tungstenite::Message {
-        // TODO: maybe some shorter way to do that?
+    fn into_tungstenite(self) -> ts::Message {
         match self {
-            Self::Text(text) => tungstenite::Message::Text(text),
-            Self::Binary(binary) => tungstenite::Message::Binary(binary),
-            Self::Ping(ping) => tungstenite::Message::Ping(ping),
-            Self::Pong(pong) => tungstenite::Message::Pong(pong),
-            Self::Close(Some(close)) => {
-                tungstenite::Message::Close(Some(tungstenite::protocol::CloseFrame {
-                    code: tungstenite::protocol::frame::coding::CloseCode::from(close.code),
-                    reason: close.reason,
-                }))
-            }
-            Self::Close(None) => tungstenite::Message::Close(None),
+            Self::Text(text) => ts::Message::Text(text),
+            Self::Binary(binary) => ts::Message::Binary(binary),
+            Self::Ping(ping) => ts::Message::Ping(ping),
+            Self::Pong(pong) => ts::Message::Pong(pong),
+            Self::Close(Some(close)) => ts::Message::Close(Some(ts::protocol::CloseFrame {
+                code: ts::protocol::frame::coding::CloseCode::from(close.code),
+                reason: close.reason,
+            })),
+            Self::Close(None) => ts::Message::Close(None),
         }
     }
 
-    fn from_tungstenite(message: tungstenite::Message) -> Self {
-        // TODO: maybe some shorter way to do that?
+    fn from_tungstenite(message: ts::Message) -> Self {
         match message {
-            tungstenite::Message::Text(text) => Self::Text(text),
-            tungstenite::Message::Binary(binary) => Self::Binary(binary),
-            tungstenite::Message::Ping(ping) => Self::Ping(ping),
-            tungstenite::Message::Pong(pong) => Self::Pong(pong),
-            tungstenite::Message::Close(Some(close)) => Self::Close(Some(CloseFrame {
+            ts::Message::Text(text) => Self::Text(text),
+            ts::Message::Binary(binary) => Self::Binary(binary),
+            ts::Message::Ping(ping) => Self::Ping(ping),
+            ts::Message::Pong(pong) => Self::Pong(pong),
+            ts::Message::Close(Some(close)) => Self::Close(Some(CloseFrame {
                 code: close.code.into(),
                 reason: close.reason,
             })),
-            tungstenite::Message::Close(None) => Self::Close(None),
+            ts::Message::Close(None) => Self::Close(None),
         }
     }
 
@@ -578,16 +574,16 @@ pub mod rejection {
 
     define_rejection! {
         #[status = BAD_REQUEST]
-        #[body = "`Sec-Websocket-Version` header did not include '13'"]
+        #[body = "`Sec-WebSocket-Version` header did not include '13'"]
         /// Rejection type for [`WebSocketUpgrade`](super::WebSocketUpgrade).
-        pub struct InvalidWebsocketVersionHeader;
+        pub struct InvalidWebSocketVersionHeader;
     }
 
     define_rejection! {
         #[status = BAD_REQUEST]
-        #[body = "`Sec-Websocket-Key` header missing"]
+        #[body = "`Sec-WebSocket-Key` header missing"]
         /// Rejection type for [`WebSocketUpgrade`](super::WebSocketUpgrade).
-        pub struct WebsocketKeyHeaderMissing;
+        pub struct WebSocketKeyHeaderMissing;
     }
 
     composite_rejection! {
@@ -599,8 +595,8 @@ pub mod rejection {
             MethodNotGet,
             InvalidConnectionHeader,
             InvalidUpgradeHeader,
-            InvalidWebsocketVersionHeader,
-            WebsocketKeyHeaderMissing,
+            InvalidWebSocketVersionHeader,
+            WebSocketKeyHeaderMissing,
             HeadersAlreadyExtracted,
             ExtensionsAlreadyExtracted,
         }
