@@ -62,6 +62,7 @@ where
     type Error = Infallible;
     type Future = super::future::IntoServiceFuture;
 
+    #[inline]
     fn poll_ready(&mut self, _cx: &mut Context<'_>) -> Poll<Result<(), Self::Error>> {
         // `IntoService` can only be constructed from async functions which are always ready, or from
         // `Layered` which bufferes in `<Layered as Handler>::call` and is therefore also always
@@ -75,6 +76,6 @@ where
         let handler = self.handler.clone();
         let future = Handler::call(handler, req).map(Ok::<_, Infallible> as _);
 
-        super::future::IntoServiceFuture { future }
+        super::future::IntoServiceFuture::new(future)
     }
 }
