@@ -1,22 +1,25 @@
 #![allow(clippy::blacklisted_name)]
 
+use crate::error_handling::HandleErrorLayer;
+use crate::extract::{Extension, MatchedPath};
 use crate::BoxError;
 use crate::{
     extract::{self, Path},
-    handler::{any, delete, get, on, patch, post, Handler},
+    handler::Handler,
     response::IntoResponse,
-    routing::MethodFilter,
-    service, Router,
+    routing::{any, delete, get, on, patch, post, service_method_routing as service, MethodFilter},
+    Json, Router,
 };
 use bytes::Bytes;
 use http::{
     header::{HeaderMap, AUTHORIZATION},
-    Request, Response, StatusCode, Uri,
+    Method, Request, Response, StatusCode, Uri,
 };
 use hyper::Body;
 use serde::Deserialize;
-use serde_json::json;
+use serde_json::{json, Value};
 use std::future::Ready;
+use std::sync::atomic::{AtomicUsize, Ordering};
 use std::{
     collections::HashMap,
     convert::Infallible,
@@ -24,16 +27,18 @@ use std::{
     task::{Context, Poll},
     time::Duration,
 };
-use tower::service_fn;
+use tower::{service_fn, timeout::TimeoutLayer, ServiceBuilder, ServiceExt};
+use tower_http::auth::RequireAuthorizationLayer;
 use tower_service::Service;
 
 pub(crate) use helpers::*;
 
+mod fallback;
 mod get_to_head;
 mod handle_error;
 mod helpers;
+mod merge;
 mod nest;
-mod or;
 
 #[tokio::test]
 async fn hello_world() {
@@ -249,8 +254,7 @@ async fn boxing() {
                 "hi from POST"
             }),
         )
-        .layer(tower_http::compression::CompressionLayer::new())
-        .boxed();
+        .layer(tower_http::compression::CompressionLayer::new());
 
     let client = TestClient::new(app);
 
@@ -338,7 +342,7 @@ async fn middleware_on_single_route() {
 
 #[tokio::test]
 async fn service_in_bottom() {
-    async fn handler(_req: Request<Body>) -> Result<Response<Body>, hyper::Error> {
+    async fn handler(_req: Request<Body>) -> Result<Response<Body>, Infallible> {
         Ok(Response::new(hyper::Body::empty()))
     }
 
@@ -479,29 +483,6 @@ async fn handler_into_service() {
     assert_eq!(res.text().await, "you said: hi there!");
 }
 
-#[tokio::test]
-async fn when_multiple_routes_match() {
-    let app = Router::new()
-        .route("/", post(|| async {}))
-        .route("/", get(|| async {}))
-        .route("/foo", get(|| async {}))
-        .nest("/foo", Router::new().route("/bar", get(|| async {})));
-
-    let client = TestClient::new(app);
-
-    let res = client.get("/").send().await;
-    assert_eq!(res.status(), StatusCode::OK);
-
-    let res = client.post("/").send().await;
-    assert_eq!(res.status(), StatusCode::OK);
-
-    let res = client.get("/foo/bar").send().await;
-    assert_eq!(res.status(), StatusCode::OK);
-
-    let res = client.get("/foo").send().await;
-    assert_eq!(res.status(), StatusCode::OK);
-}
-
 #[tokio::test]
 async fn captures_dont_match_empty_segments() {
     let app = Router::new().route("/:key", get(|| async {}));
@@ -515,6 +496,312 @@ async fn captures_dont_match_empty_segments() {
     assert_eq!(res.status(), StatusCode::OK);
 }
 
+#[tokio::test]
+async fn json_content_types() {
+    async fn valid_json_content_type(content_type: &str) -> bool {
+        println!("testing {:?}", content_type);
+
+        let app = Router::new().route("/", post(|Json(_): Json<Value>| async {}));
+
+        let res = TestClient::new(app)
+            .post("/")
+            .header("content-type", content_type)
+            .body("{}")
+            .send()
+            .await;
+
+        res.status() == StatusCode::OK
+    }
+
+    assert!(valid_json_content_type("application/json").await);
+    assert!(valid_json_content_type("application/json; charset=utf-8").await);
+    assert!(valid_json_content_type("application/json;charset=utf-8").await);
+    assert!(valid_json_content_type("application/cloudevents+json").await);
+    assert!(!valid_json_content_type("text/json").await);
+}
+
+#[tokio::test]
+async fn wildcard_sees_whole_url() {
+    let app = Router::new().route("/api/*rest", get(|uri: Uri| async move { uri.to_string() }));
+
+    let client = TestClient::new(app);
+
+    let res = client.get("/api/foo/bar").send().await;
+    assert_eq!(res.text().await, "/api/foo/bar");
+}
+
+#[tokio::test]
+async fn middleware_applies_to_routes_above() {
+    let app = Router::new()
+        .route("/one", get(std::future::pending::<()>))
+        .layer(
+            ServiceBuilder::new()
+                .layer(HandleErrorLayer::new(|_: BoxError| {
+                    StatusCode::REQUEST_TIMEOUT
+                }))
+                .layer(TimeoutLayer::new(Duration::new(0, 0))),
+        )
+        .route("/two", get(|| async {}));
+
+    let client = TestClient::new(app);
+
+    let res = client.get("/one").send().await;
+    assert_eq!(res.status(), StatusCode::REQUEST_TIMEOUT);
+
+    let res = client.get("/two").send().await;
+    assert_eq!(res.status(), StatusCode::OK);
+}
+
+#[tokio::test]
+async fn with_trailing_slash() {
+    let app = Router::new().route("/foo", get(|| async {}));
+
+    let client = TestClient::new(app);
+
+    // `TestClient` automatically follows redirects
+    let res = client.get("/foo/").send().await;
+    assert_eq!(res.status(), StatusCode::OK);
+}
+
+#[tokio::test]
+async fn without_trailing_slash() {
+    let app = Router::new().route("/foo/", get(|| async {}));
+
+    let client = TestClient::new(app);
+
+    // `TestClient` automatically follows redirects
+    let res = client.get("/foo").send().await;
+    assert_eq!(res.status(), StatusCode::OK);
+}
+
+#[tokio::test]
+async fn with_and_without_trailing_slash() {
+    let app = Router::new()
+        .route("/foo", get(|| async { "without tsr" }))
+        .route("/foo/", get(|| async { "with tsr" }));
+
+    let client = TestClient::new(app);
+
+    let res = client.get("/foo/").send().await;
+    assert_eq!(res.status(), StatusCode::OK);
+    assert_eq!(res.text().await, "with tsr");
+
+    let res = client.get("/foo").send().await;
+    assert_eq!(res.status(), StatusCode::OK);
+    assert_eq!(res.text().await, "without tsr");
+}
+
+// for https://github.com/tokio-rs/axum/issues/420
+#[tokio::test]
+async fn wildcard_with_trailing_slash() {
+    #[derive(Deserialize, serde::Serialize)]
+    struct Tree {
+        user: String,
+        repo: String,
+        path: String,
+    }
+
+    let app: Router = Router::new().route(
+        "/:user/:repo/tree/*path",
+        get(|Path(tree): Path<Tree>| async move { Json(tree) }),
+    );
+
+    // low level check that the correct redirect happens
+    let res = app
+        .clone()
+        .oneshot(
+            Request::builder()
+                .method(Method::GET)
+                .uri("/user1/repo1/tree")
+                .body(Body::empty())
+                .unwrap(),
+        )
+        .await
+        .unwrap();
+    assert_eq!(res.status(), StatusCode::MOVED_PERMANENTLY);
+    assert_eq!(res.headers()["location"], "/user1/repo1/tree/");
+
+    // check that the params are deserialized correctly
+    let client = TestClient::new(app);
+    let res = client.get("/user1/repo1/tree/").send().await;
+    assert_eq!(
+        res.json::<Value>().await,
+        json!({
+            "user": "user1",
+            "repo": "repo1",
+            "path": "/",
+        })
+    );
+}
+
+#[derive(Clone)]
+struct SetMatchedPathExtension<S>(S);
+
+impl<B, S> Service<Request<B>> for SetMatchedPathExtension<S>
+where
+    S: Service<Request<B>>,
+{
+    type Response = S::Response;
+    type Error = S::Error;
+    type Future = S::Future;
+
+    fn poll_ready(&mut self, cx: &mut Context<'_>) -> Poll<Result<(), Self::Error>> {
+        self.0.poll_ready(cx)
+    }
+
+    fn call(&mut self, mut req: Request<B>) -> Self::Future {
+        let path = req
+            .extensions()
+            .get::<MatchedPath>()
+            .unwrap()
+            .as_str()
+            .to_string();
+        req.extensions_mut().insert(MatchedPathFromMiddleware(path));
+        self.0.call(req)
+    }
+}
+
+#[derive(Clone)]
+struct MatchedPathFromMiddleware(String);
+
+#[tokio::test]
+async fn access_matched_path() {
+    let api = Router::new().route(
+        "/users/:id",
+        get(|path: MatchedPath| async move { path.as_str().to_string() }),
+    );
+
+    async fn handler(
+        path: MatchedPath,
+        Extension(MatchedPathFromMiddleware(path_from_middleware)): Extension<
+            MatchedPathFromMiddleware,
+        >,
+    ) -> String {
+        format!(
+            "extractor = {}, middleware = {}",
+            path.as_str(),
+            path_from_middleware
+        )
+    }
+
+    let app = Router::new()
+        .route(
+            "/:key",
+            get(|path: MatchedPath| async move { path.as_str().to_string() }),
+        )
+        .nest("/api", api)
+        .nest(
+            "/public",
+            Router::new().route("/assets/*path", get(handler)),
+        )
+        .nest("/foo", handler.into_service())
+        .layer(tower::layer::layer_fn(SetMatchedPathExtension));
+
+    let client = TestClient::new(app);
+
+    let res = client.get("/foo").send().await;
+    assert_eq!(res.text().await, "/:key");
+
+    let res = client.get("/api/users/123").send().await;
+    assert_eq!(res.text().await, "/api/users/:id");
+
+    let res = client.get("/public/assets/css/style.css").send().await;
+    assert_eq!(
+        res.text().await,
+        "extractor = /public/assets/*path, middleware = /public/assets/*path"
+    );
+
+    let res = client.get("/foo/bar/baz").send().await;
+    assert_eq!(
+        res.text().await,
+        format!(
+            "extractor = /foo/*{}, middleware = /foo/*{}",
+            crate::routing::NEST_TAIL_PARAM,
+            crate::routing::NEST_TAIL_PARAM,
+        ),
+    );
+}
+
+#[tokio::test]
+async fn static_and_dynamic_paths() {
+    let app = Router::new()
+        .route(
+            "/:key",
+            get(|Path(key): Path<String>| async move { format!("dynamic: {}", key) }),
+        )
+        .route("/foo", get(|| async { "static" }));
+
+    let client = TestClient::new(app);
+
+    let res = client.get("/bar").send().await;
+    assert_eq!(res.text().await, "dynamic: bar");
+
+    let res = client.get("/foo").send().await;
+    assert_eq!(res.text().await, "static");
+}
+
+#[tokio::test]
+#[should_panic(expected = "Invalid route: empty path")]
+async fn empty_route() {
+    let app = Router::new().route("", get(|| async {}));
+    TestClient::new(app);
+}
+
+#[tokio::test]
+#[should_panic(expected = "Invalid route: empty path")]
+async fn empty_route_nested() {
+    let app = Router::new().nest("", get(|| async {}));
+    TestClient::new(app);
+}
+
+#[tokio::test]
+async fn middleware_still_run_for_unmatched_requests() {
+    #[derive(Clone)]
+    struct CountMiddleware<S>(S);
+
+    static COUNT: AtomicUsize = AtomicUsize::new(0);
+
+    impl<R, S> Service<R> for CountMiddleware<S>
+    where
+        S: Service<R>,
+    {
+        type Response = S::Response;
+        type Error = S::Error;
+        type Future = S::Future;
+
+        fn poll_ready(&mut self, cx: &mut Context<'_>) -> Poll<Result<(), Self::Error>> {
+            self.0.poll_ready(cx)
+        }
+
+        fn call(&mut self, req: R) -> Self::Future {
+            COUNT.fetch_add(1, Ordering::SeqCst);
+            self.0.call(req)
+        }
+    }
+
+    let app = Router::new()
+        .route("/", get(|| async {}))
+        .layer(tower::layer::layer_fn(CountMiddleware));
+
+    let client = TestClient::new(app);
+
+    assert_eq!(COUNT.load(Ordering::SeqCst), 0);
+
+    client.get("/").send().await;
+    assert_eq!(COUNT.load(Ordering::SeqCst), 1);
+
+    client.get("/not-found").send().await;
+    assert_eq!(COUNT.load(Ordering::SeqCst), 2);
+}
+
+#[tokio::test]
+#[should_panic(
+    expected = "Invalid route: `Router::route` cannot be used with `Router`s. Use `Router::nest` instead"
+)]
+async fn routing_to_router_panics() {
+    TestClient::new(Router::new().route("/", Router::new()));
+}
+
 pub(crate) fn assert_send<T: Send>() {}
 pub(crate) fn assert_sync<T: Sync>() {}
 pub(crate) fn assert_unpin<T: Unpin>() {}
